@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::Author::GETTY::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: BeLike::GETTY when you build your dists
-$Dist::Zilla::PluginBundle::Author::GETTY::VERSION = '0.106';
+$Dist::Zilla::PluginBundle::Author::GETTY::VERSION = '0.107';
 use Moose;
 use Moose::Autobox;
 use Dist::Zilla;
@@ -208,23 +208,19 @@ sub configure {
   $self->log_fatal("no_install can't be used together with no_makemaker")
     if $self->no_install and $self->no_makemaker;
 
+  $self->add_plugins(qw(
+    Git::GatherDir
+  ));
+
+  my @removes = ('GatherDir');
   if ($self->no_cpan || $self->no_makemaker) {
-    my @removes;
     push @removes, 'UploadToCPAN' if $self->no_cpan;
     push @removes, 'MakeMaker' if $self->no_makemaker;
-    $self->add_bundle('Filter' => {
-      -bundle => '@Basic',
-      -remove => [@removes],
-    });
-  } else {
-    $self->add_bundle('@Basic');
-  }
-
-  if ($self->no_install) {
-    $self->add_plugins(qw(
-      MakeMaker::SkipInstall
-    ));
   }
+  $self->add_bundle('Filter' => {
+    -bundle => '@Basic',
+    -remove => [@removes],
+  });
 
   unless ($self->manual_version) {
     if ($self->is_task) {
@@ -375,7 +371,7 @@ Dist::Zilla::PluginBundle::Author::GETTY - BeLike::GETTY when you build your dis
 
 =head1 VERSION
 
-version 0.106
+version 0.107
 
 =head1 SYNOPSIS
 
